;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "llama" "20260601.1455"
  "Compact syntax for short lambda."
  '((emacs  "26.1")
    (compat "31.0"))
  :url "https://github.com/tarsius/llama"
  :commit "4d4024048053b898a01521046e0f063ee47615b0"
  :revdesc "4d4024048053"
  :keywords '("extensions")
  :authors '(("Jonas Bernoulli" . "emacs.llama@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.llama@jonas.bernoulli.dev")))
